:orphan:

Abjad 2.2
---------

Released 2011-08-30. Built from r4677. 

* Added articulations chapter to reference manual.
* Reordered the way in which Abjad determines the value of the ``home`` environment variable.
* Updated ``scr/devel/replace-in-files`` to avoid image files.
* Updated ``systemtools.log()`` to call operating-specific text editor.
